@@ -3,18 +3,17 @@
 # This software is licensed under the terms of the Apache Licence Version 2.0
 # which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
 # In applying this licence, ECMWF does not waive the privileges and immunities
-# granted to it by virtue of its status as an intergovernmental organisation nor
-# does it submit to any jurisdiction.
+# granted to it by virtue of its status as an intergovernmental organisation
+# nor does it submit to any jurisdiction.
 #
 
 
 class NoneHelper:
-    def __init__(self, *args, **kwargs):
-        self.kwargs = kwargs
+    def __init__(self, data):
+        pass
 
     def plot_map(self, driver):
         driver.style(None)
-        driver.apply_kwargs(self.kwargs)
 
 
 helper = NoneHelper
